@@ -1,7 +1,7 @@
 """develop tests
 """
-import mock
 import sys
+from unittest import mock
 
 import pytest
 
@@ -10,6 +10,7 @@ from setuptools import SetuptoolsDeprecationWarning
 
 
 @pytest.mark.skipif(sys.platform == 'win32', reason='non-Windows only')
+@pytest.mark.xfail(reason="bdist_rpm is long deprecated, should we remove it? #1988")
 @mock.patch('distutils.command.bdist_rpm.bdist_rpm')
 def test_bdist_rpm_warning(distutils_cmd, tmpdir_cwd):
     dist = Distribution(
