@@ -286,7 +286,7 @@ def test_maintainer_author(name, attrs, tmpdir):
 
     dist.metadata.write_pkg_info(fn_s)
 
-    with io.open(str(fn.join('PKG-INFO')), 'r', encoding='utf-8') as f:
+    with open(str(fn.join('PKG-INFO')), 'r', encoding='utf-8') as f:
         pkg_info = f.read()
 
     assert _valid_metadata(pkg_info)
@@ -357,7 +357,7 @@ def test_parity_with_metadata_from_pypa_wheel(tmp_path):
     for line in expected:
         assert line in pkg_info
 
-    # Generate a METADATA file using pypa/wheel for comparisson
+    # Generate a METADATA file using pypa/wheel for comparison
     wheel_metadata = importlib.import_module("wheel.metadata")
     pkginfo_to_metadata = getattr(wheel_metadata, "pkginfo_to_metadata", None)
 
